/// <reference types="node" />
import { BitField, GuildCreateChannelOptions, GuildCreateOptions } from "discord.js";
import { Stream } from "stream";
export interface IAuthor {
  icon_url: string;
  name: string;
  url: string;
}
export interface IField {
  name: string;
  inline: boolean;
  value: string;
}
export interface IImage {
  url: string;
}
export interface IThumbnail {
  url: string;
}
export interface IEmoji {
  id?: string;
  name?: string;
}
export interface IMinifiedEmbedMessage {
  author: IAuthor;
  color: number;
  description: string;
  fields: IField[];
  footer?: any;
  image: IImage;
  thumbnail: IThumbnail;
  timestamp?: any;
  title: string;
  type: string;
  url: string;
}
export interface IMessageIdentifier {
  /**
   * Text of a message, use it to find a message if you don't know
   * it's **id**.
   *
   * If there is more than one message with the same content,
   * Corde will handle the latest message sent.
   *
   * ps: To avoid possible inconsistencies, recommend using **id** for message search.
   */
  content?: string;
  /**
   * IIdentifier of the message
   */
  id?: string;
}
export interface IIdentifier {
  id?: string;
}
export interface IRoleIdentifier extends IIdentifier {
  name?: string;
}
export interface IChannelIdentifier extends IIdentifier {
  name?: string;
}
export declare type ChannelType = "voice" | "text" | "category";
export interface IGuildCreateOptions extends GuildCreateOptions {
  name: string;
}
export interface ICreateChannelOptions extends GuildCreateChannelOptions {
  name: string;
}
export interface ICreateChannelOptionsSimple extends Omit<ICreateChannelOptions, "type"> {}
export interface IGuildIdentifier extends IIdentifier {
  name?: string;
}
export interface IBaseRole {
  name?: string;
  color?: ColorResolvable | Colors;
  isHoist?: boolean;
  position?: number;
  permissions?: RolePermission;
  isMentionable?: boolean;
}
/**
 * Object contract used to identify messages in message edition tests.
 */
export interface IMessageEditedIdentifier {
  /**
   * IIdentifier of the message
   */
  id?: string;
  /**
   * Old content of the message to identify it.
   */
  oldContent?: string;
}
export interface IMessageEmbedFooter {
  /**
   * footer text
   */
  text?: string;
  /**
   * URL of footer icon (only supports HTTP(s) and attachments)
   */
  iconURL?: string;
}
export interface IMessageEmbedImage {
  /**
   * source URL of the image (only supports HTTP(s) and attachments)
   */
  url: string;
  /**
   * Height of the image
   */
  height?: number;
  /**
   * width of the image
   */
  width?: number;
}
export interface IMessageEmbedThumbnail {
  /**
   * Url of the thumbnail
   */
  url: string;
  /**
   * Height of the thumbnail
   */
  height?: number;
  /**
   * width of the thumbnail
   */
  width?: number;
}
export interface IFile {
  /**
   * Buffer, URL, or stream of the file.
   *
   * @see https://nodejs.org/api/stream.html
   * @see https://nodejs.org/api/buffer.html
   */
  attachment: Buffer | string | Stream;
  /**
   * Name of the file
   */
  name?: string | null;
}
export interface IEmbedFieldData {
  name: string;
  value: string;
  inline?: boolean;
}
export interface IMessageEmbedAuthor {
  name?: string;
  url?: string;
  iconURL?: string;
}
/**
 * Main and optional information about an embedded message.
 */
export interface IMessageEmbed {
  /**
   * author name **or** information
   */
  author?: IMessageEmbedAuthor | string;
  /**
   * color code of the embed
   */
  color?: ColorResolvable;
  /**
   * description of embed
   */
  description?: string;
  /**
   * fields information. An array of embed field objects
   */
  fields?: IEmbedFieldData[];
  /**
   * files URLs **or** information of the embed.
   */
  files?: (IFile | string)[];
  /**
   * Footer url **or** information
   */
  footer?: IMessageEmbedFooter | string;
  /**
   * IImage URL **or** information
   */
  image?: IMessageEmbedImage | string;
  /**
   * Source url of thumbnail (only supports HTTP(s) and attachments)
   */
  thumbnailUrl?: string;
  /**
   * Timestamp of embed content **or** a Date object
   */
  timestamp?: number | Date;
  /**
   * Title of embed
   */
  title?: string;
  /**
   * Url of embed
   */
  url?: string;
}
export declare type Base64Resolvable = Buffer | string;
export declare type VerificationLevelType = "NONE" | "LOW" | "MEDIUM" | "HIGH" | "VERY_HIGH";
/**
 * @see https://discord.com/developers/docs/resources/guild#guild-object-verification-level
 */
export declare enum VerificationLevel {
  /**
   * Unrestricted
   */
  NONE = "NONE",
  /**
   * Must have verified email on account
   */
  LOW = "LOW",
  /**
   * Must be registered on Discord for longer than 5 minutes
   */
  MEDIUM = "MEDIUM",
  /**
   * Must be a member of the server for longer than 10 minutes
   */
  HIGH = "HIGH",
  /**
   * Must have a verified phone number
   */
  VERY_HIGH = "VERY_HIGH",
}
export declare type ColorResolvable =
  | "DEFAULT"
  | "WHITE"
  | "AQUA"
  | "GREEN"
  | "BLUE"
  | "YELLOW"
  | "PURPLE"
  | "LUMINOUS_VIVID_PINK"
  | "GOLD"
  | "ORANGE"
  | "RED"
  | "GREY"
  | "DARKER_GREY"
  | "NAVY"
  | "DARK_AQUA"
  | "DARK_GREEN"
  | "DARK_BLUE"
  | "DARK_PURPLE"
  | "DARK_VIVID_PINK"
  | "DARK_GOLD"
  | "DARK_ORANGE"
  | "DARK_RED"
  | "DARK_GREY"
  | "LIGHT_GREY"
  | "DARK_NAVY"
  | "BLURPLE"
  | "GREYPLE"
  | "DARK_BUT_NOT_BLACK"
  | "NOT_QUITE_BLACK"
  | "RANDOM"
  | [number, number, number]
  | number
  | ColorsHex
  | Colors
  | string;
export declare type ImageSize = 16 | 32 | 64 | 128 | 256 | 512 | 1024 | 2048 | 4096;
export declare type AllowedImageFormat = "webp" | "png" | "jpg" | "jpeg" | "gif";
/**
 * @see https://discord.com/developers/docs/resources/guild#guild-object-guild-features
 */
export declare type GuildFeaturesType =
  | "ANIMATED_ICON"
  | "BANNER"
  | "COMMERCE"
  | "COMMUNITY"
  | "DISCOVERABLE"
  | "FEATURABLE"
  | "INVITE_SPLASH"
  | "NEWS"
  | "PARTNERED"
  | "RELAY_ENABLED"
  | "VANITY_URL"
  | "VERIFIED"
  | "VIP_REGIONS"
  | "WELCOME_SCREEN_ENABLED";
/**
 * Defines Guild's features
 *
 * @see https://discord.com/developers/docs/resources/guild#guild-object-guild-features
 */
export declare enum GuildFeatures {
  /**
   * Guild has access to set an invite splash background
   */
  INVITE_SPLASH = "INVITE_SPLASH",
  /**
   * Guild has access to set 384kbps bitrate in voice (previously VIP voice servers)
   */
  VIP_REGIONS = "VIP_REGIONS",
  /**
   * Guild has access to set a vanity URL
   */
  VANITY_URL = "VANITY_URL",
  /**
   * Guild is verified
   */
  VERIFIED = "VERIFIED",
  /**
   * Guild is partnered
   */
  PARTNERED = "PARTNERED",
  /**
   * Guild can enable welcome screen, Membership Screening, and discovery, and receives community updates
   */
  COMMUNITY = "COMMUNITY",
  /**
   * Guild has access to use commerce features (i.e. create store channels)
   */
  COMMERCE = "COMMERCE",
  /**
   * Guild has access to create news channels
   */
  NEWS = "NEWS",
  /**
   * Guild can be discovered in the directory
   */
  DISCOVERABLE = "DISCOVERABLE",
  /**
   * Guild can be featured in the directory
   */
  FEATURABLE = "FEATURABLE",
  /**
   * Guild has access to set an animated guild icon
   */
  ANIMATED_ICON = "ANIMATED_ICON",
  /**
   * Guild has access to set a guild banner image
   */
  BANNER = "BANNER",
  /**
   * Guild has enabled the welcome screen
   */
  WELCOME_SCREEN_ENABLED = "WELCOME_SCREEN_ENABLED",
  /**
   * Guild has enabled [Membership Screening](https://discord.com/developers/docs/resources/guild#membership-screening-object)
   */
  MEMBER_VERIFICATION_GATE_ENABLED = "MEMBER_VERIFICATION_GATE_ENABLED",
  /**
   * Guild can be previewed before joining via Membership Screening or the directory
   */
  PREVIEW_ENABLED = "PREVIEW_ENABLED",
}
export declare type RecursiveReadonlyArray<T> = ReadonlyArray<T | RecursiveReadonlyArray<T>>;
export declare type SystemChannelFlagsString =
  | "WELCOME_MESSAGE_DISABLED"
  | "BOOST_MESSAGE_DISABLED";
export declare type SystemChannelFlagsResolvable = BitFieldResolvable<SystemChannelFlagsString>;
export declare type BitFieldResolvable<T extends string> =
  | RecursiveReadonlyArray<T | number | Readonly<BitField<T>>>
  | T
  | number
  | Readonly<BitField<T>>;
export interface IImageURLOptions {
  format?: AllowedImageFormat;
  size?: ImageSize;
}
/**
 * System channel flags of Discord
 *
 * @see https://discord.com/developers/docs/resources/guild#guild-object-system-channel-flags
 */
export declare enum SystemChannelFlag {
  /**
   * Suppress member join notifications
   */
  SUPPRESS_JOIN_NOTIFICATIONS = "SUPPRESS_JOIN_NOTIFICATIONS",
  /**
   * Suppress server boost notifications
   */
  SUPPRESS_PREMIUM_SUBSCRIPTIONS = "SUPPRESS_PREMIUM_SUBSCRIPTIONS",
}
export declare type Locale =
  | "af-ZA"
  | "am-ET"
  | "ar-AE"
  | "ar-BH"
  | "ar-DZ"
  | "ar-EG"
  | "ar-IQ"
  | "ar-JO"
  | "ar-KW"
  | "ar-LB"
  | "ar-LY"
  | "ar-MA"
  | "arn-CL"
  | "ar-OM"
  | "ar-QA"
  | "ar-SA"
  | "ar-SY"
  | "ar-TN"
  | "ar-YE"
  | "as-IN"
  | "az-Cyrl-AZ"
  | "az-Latn-AZ"
  | "ba-RU"
  | "be-BY"
  | "bg-BG"
  | "bn-BD"
  | "bn-IN"
  | "bo-CN"
  | "br-FR"
  | "bs-Cyrl-BA"
  | "bs-Latn-BA"
  | "ca-ES"
  | "co-FR"
  | "cs-CZ"
  | "cy-GB"
  | "da-DK"
  | "de-AT"
  | "de-CH"
  | "de-DE"
  | "de-LI"
  | "de-LU"
  | "dsb-DE"
  | "dv-MV"
  | "el-GR"
  | "en-029"
  | "en-AU"
  | "en-BZ"
  | "en-CA"
  | "en-GB"
  | "en-IE"
  | "en-IN"
  | "en-JM"
  | "en-MY"
  | "en-NZ"
  | "en-PH"
  | "en-SG"
  | "en-TT"
  | "en-US"
  | "en-ZA"
  | "en-ZW"
  | "es-AR"
  | "es-BO"
  | "es-CL"
  | "es-CO"
  | "es-CR"
  | "es-DO"
  | "es-EC"
  | "es-ES"
  | "es-GT"
  | "es-HN"
  | "es-MX"
  | "es-NI"
  | "es-PA"
  | "es-PE"
  | "es-PR"
  | "es-PY"
  | "es-SV"
  | "es-US"
  | "es-UY"
  | "es-VE"
  | "et-EE"
  | "eu-ES"
  | "fa-IR"
  | "fi-FI"
  | "fil-PH"
  | "fo-FO"
  | "fr-BE"
  | "fr-CA"
  | "fr-CH"
  | "fr-FR"
  | "fr-LU"
  | "fr-MC"
  | "fy-NL"
  | "ga-IE"
  | "gd-GB"
  | "gl-ES"
  | "gsw-FR"
  | "gu-IN"
  | "ha-Latn-NG"
  | "he-IL"
  | "hi-IN"
  | "hr-BA"
  | "hr-HR"
  | "hsb-DE"
  | "hu-HU"
  | "hy-AM"
  | "id-ID"
  | "ig-NG"
  | "ii-CN"
  | "is-IS"
  | "it-CH"
  | "it-IT"
  | "iu-Cans-CA"
  | "iu-Latn-CA"
  | "ja-JP"
  | "ka-GE"
  | "kk-KZ"
  | "kl-GL"
  | "km-KH"
  | "kn-IN"
  | "kok-IN"
  | "ko-KR"
  | "ky-KG"
  | "lb-LU"
  | "lo-LA"
  | "lt-LT"
  | "lv-LV"
  | "mi-NZ"
  | "mk-MK"
  | "ml-IN"
  | "mn-MN"
  | "mn-Mong-CN"
  | "moh-CA"
  | "mr-IN"
  | "ms-BN"
  | "ms-MY"
  | "mt-MT"
  | "nb-NO"
  | "ne-NP"
  | "nl-BE"
  | "nl-NL"
  | "nn-NO"
  | "nso-ZA"
  | "oc-FR"
  | "or-IN"
  | "pa-IN"
  | "pl-PL"
  | "prs-AF"
  | "ps-AF"
  | "pt-BR"
  | "pt-PT"
  | "qut-GT"
  | "quz-BO"
  | "quz-EC"
  | "quz-PE"
  | "rm-CH"
  | "ro-RO"
  | "ru-RU"
  | "rw-RW"
  | "sah-RU"
  | "sa-IN"
  | "se-FI"
  | "se-NO"
  | "se-SE"
  | "si-LK"
  | "sk-SK"
  | "sl-SI"
  | "sma-NO"
  | "sma-SE"
  | "smj-NO"
  | "smj-SE"
  | "smn-FI"
  | "sms-FI"
  | "sq-AL"
  | "sr-Cyrl-BA"
  | "sr-Cyrl-CS"
  | "sr-Cyrl-ME"
  | "sr-Cyrl-RS"
  | "sr-Latn-BA"
  | "sr-Latn-CS"
  | "sr-Latn-ME"
  | "sr-Latn-RS"
  | "sv-FI"
  | "sv-SE"
  | "sw-KE"
  | "syr-SY"
  | "ta-IN"
  | "te-IN"
  | "tg-Cyrl-TJ"
  | "th-TH"
  | "tk-TM"
  | "tn-ZA"
  | "tr-TR"
  | "tt-RU"
  | "tzm-Latn-DZ"
  | "ug-CN"
  | "uk-UA"
  | "ur-PK"
  | "uz-Cyrl-UZ"
  | "uz-Latn-UZ"
  | "vi-VN"
  | "wo-SN"
  | "xh-ZA"
  | "yo-NG"
  | "zh-CN"
  | "zh-HK"
  | "zh-MO"
  | "zh-SG"
  | "zh-TW"
  | "zu-ZA";
export interface IRoleData {
  name?: string;
  color?: ColorResolvable;
  hoist?: boolean;
  position?: number;
  permissions?: RolePermission;
  mentionable?: boolean;
}
export interface IMessageAuthor {
  id: string;
  isBot: boolean;
  createdAt: Date;
  username: string;
}
export declare namespace Config {
  interface ICLIOptions {
    files: string;
    config: string;
  }
}
export declare enum ColorsHex {
  DEFAULT = 0,
  WHITE = 16777215,
  AQUA = 1752220,
  GREEN = 3066993,
  BLUE = 3447003,
  YELLOW = 16776960,
  PURPLE = 10181046,
  LUMINOUS_VIVID_PINK = 15277667,
  GOLD = 15844367,
  ORANGE = 15105570,
  RED = 15158332,
  GREY = 9807270,
  NAVY = 3426654,
  DARK_AQUA = 1146986,
  DARK_GREEN = 2067276,
  DARK_BLUE = 2123412,
  DARK_PURPLE = 7419530,
  DARK_VIVID_PINK = 11342935,
  DARK_GOLD = 12745742,
  DARK_ORANGE = 11027200,
  DARK_RED = 10038562,
  DARK_GREY = 9936031,
  DARKER_GREY = 8359053,
  LIGHT_GREY = 12370112,
  DARK_NAVY = 2899536,
  BLURPLE = 7506394,
  GREYPLE = 10070709,
  DARK_BUT_NOT_BLACK = 2895667,
  NOT_QUITE_BLACK = 2303786,
}
export declare enum Colors {
  DEFAULT = "#000000",
  WHITE = "#FFFFFF",
  AQUA = "#1ABC9C",
  GREEN = "#2ECC71",
  BLUE = "#3498DB",
  PURPLE = "#9B59B6",
  GOLD = "#E91E63",
  ORANGE = "#E67E22",
  RED = "#E74C3C",
  GREY = "#95A5A6",
  DARKER_GREY = "#7F8C8D",
  NAVY = "#34495E",
  DARK_AQUA = "#11806A",
  DARK_GREEN = "#1F8B4C",
  DARK_BLUE = "#206694",
  DARK_PURPLE = "#71368A",
  DARK_GOLD = "#C27C0E",
  DARK_ORANGE = "#A84300",
  DARK_RED = "#992D22",
  DARK_GREY = "#7F8C8D",
  LIGHT_GREY = "#BCC0C0",
  DARK_NAVY = "#2C3E50",
  LUMINOUS_VIVID_PINK = "#E91E63",
  DARK_VIVID_PINK = "#AD1457",
}
export declare type RolePermission =
  | "CREATE_INSTANT_INVITE"
  | "KICK_MEMBERS"
  | "BAN_MEMBERS"
  | "ADMINISTRATOR"
  | "MANAGE_CHANNELS"
  | "MANAGE_GUILD"
  | "ADD_REACTIONS"
  | "VIEW_AUDIT_LOG"
  | "PRIORITY_SPEAKER"
  | "STREAM"
  | "VIEW_CHANNEL"
  | "SEND_MESSAGES"
  | "SEND_TTS_MESSAGES"
  | "MANAGE_MESSAGES"
  | "EMBED_LINKS"
  | "ATTACH_FILES"
  | "READ_MESSAGE_HISTORY"
  | "MENTION_EVERYONE"
  | "USE_EXTERNAL_EMOJIS"
  | "VIEW_GUILD_INSIGHTS"
  | "CONNECT"
  | "SPEAK"
  | "MUTE_MEMBERS"
  | "DEAFEN_MEMBERS"
  | "MOVE_MEMBERS"
  | "USE_VAD"
  | "CHANGE_NICKNAME"
  | "MANAGE_NICKNAMES"
  | "MANAGE_ROLES"
  | "MANAGE_WEBHOOKS"
  | "MANAGE_EMOJIS";
/**
 * Enum with of all current permissions of Discord, their integer values in hexadecimal.
 *
 * https://discord.com/developers/docs/topics/permissions#permissions-bitwise-permission-flags
 */
export declare enum Permission {
  /**
   * Allows creation of instant invites
   * @summary For **Text** and **Voice** Channel
   */
  CREATE_INSTANT_INVITE = 1,
  /**
   * Allows kicking members
   * @summary Indifferent of channel
   */
  KICK_MEMBERS = 2,
  /**
   * Allows banning members
   * @summary Indifferent of channel
   */
  BAN_MEMBERS = 4,
  /**
   * Allows all permissions and bypasses channel permission overwrites.
   * @summary Indifferent of channel
   */
  ADMINISTRATOR = 8,
  /**
   * Allows management and editing of channels
   * @summary For **Text** and **Voice** Channel
   */
  MANAGE_CHANNELS = 16,
  /**
   * Allows management and editing of the guild
   * @summary For **Text** and **Voice** Channel
   */
  MANAGE_GUILD = 32,
  /**
   * Allows for the addition of reactions to messages
   * @summary For **Text** Channel only
   */
  ADD_REACTIONS = 64,
  /**
   * Allows for viewing of audit logs
   * @summary For **Text** and **Voice** Channel
   */
  VIEW_AUDIT_LOG = 128,
  /**
   * Allows guild members to view a channel, which includes reading messages in text channels
   * @summary Indifferent of channel
   */
  VIEW_CHANNEL = 1024,
  /**
   * Allows for sending messages in a channel
   * @summary For **Text** Channel only
   */
  SEND_MESSAGES = 2048,
  /**
   * Allows for sending of /tts messages
   * @summary For **Text** Channel only
   */
  SEND_TTS_MESSAGES = 4096,
  /**
   * Allows for deletion of other users messages
   * @summary For **Text** Channel only
   */
  MANAGE_MESSAGES = 8192,
  /**
   * Links sent by users with this permission will be auto-embedded
   * @summary For **Text** Channel only
   */
  EMBED_LINKS = 16384,
  /**
   * Allows for uploading images and files
   * @summary For **Text** Channel only
   */
  ATTACH_FILES = 32768,
  /**
   * Allows for reading of message history
   * @summary For **Text** Channel only
   */
  READ_MESSAGE_HISTORY = 65536,
  /**
   * Allows for using the @everyone tag to notify all users in a channel,
   * and the @here tag to notify all online users in a channel
   * @summary For **Text** Channel only
   */
  MENTION_EVERYONE = 131072,
  /**
   * Allows the usage of custom emojis from other servers
   * @summary For **Text** Channel only
   */
  USE_EXTERNAL_EMOJIS = 262144,
  /**
   * Allows for joining of a voice channel
   * @summary For **Voice** Channel only
   */
  CONNECT = 1048576,
  /**
   * Allows for speaking in a voice channel
   * @summary For **Voice** Channel only
   */
  SPEAK = 2097152,
  /**
   * Allows for muting members in a voice channel
   * @summary For **Voice** Channel only
   */
  MUTE_MEMBERS = 4194304,
  /**
   * Allows for deafening of members in a voice channel
   * @summary For **Voice** Channel only
   */
  DEAFEN_MEMBERS = 8388608,
  /**
   * Allows for moving of members between voice channels
   * @summary For **Voice** Channel only
   */
  MOVE_MEMBERS = 16777216,
  /**
   * Allows for using voice-activity-detection in a voice channel
   * @summary For **Voice** Channel only
   */
  USE_VAD = 33554432,
  /**
   * Allows for using priority speaker in a voice channel
   * @summary For **Voice** Channel only
   */
  PRIORITY_SPEAKER = 256,
  /**
   * Allows for modification of own nickname
   * @summary Indifferent of channel
   */
  CHANGE_NICKNAME = 67108864,
  /**
   * Allows for modification of other users nicknames
   * @summary Indifferent of channel
   */
  MANAGE_NICKNAMES = 134217728,
  /**
   * Allows management and editing of roles
   * @summary For **Text** and **Voice** Channel
   */
  MANAGE_ROLES = 268435456,
  /**
   * Allows management and editing of webhooks
   * @summary For **Text** and **Voice** Channel
   */
  MANAGE_WEBHOOKS = 536870912,
  /**
   * Allows management and editing of emojis
   * @summary Indifferent of channel
   */
  MANAGE_EMOJIS = 1073741824,
  /**
   * Allows the user to go live
   * @summary For **Voice** Channel only
   */
  STREAM = 512,
  /**
   * Allows for viewing guild insights
   * @summary Indifferent of channel
   */
  VIEW_GUILD_INSIGHTS = 524288,
}
declare const permissionsArray: string[];
export { permissionsArray };
